
# fraplib's Documentation

functions for displaying and calculating frap experiment stuff


## Basic Usage

```python
# a basic usage example can go here
print(1+1)
```

## Install
```bash
pip install fraplib
```



```{toctree}
:maxdepth: 2

API <api/fraplib>
contributing
```

```{toctree}
:caption: Examples
:maxdepth: 1

examples/basic-example.ipynb
```
